# jp2totiff - Convert jpeg2000 raster to tiff raster 

Python implementation to convert jp2 raster images typically from Sentienl-2 satellite platform to tiff raster.

[Saif Aati](mailto:saif@caltech.edu)
    - saif@caltech.edu
    - saifaati@gmail.com

`jp2totiff` is a Python library and command line tool for converting jp2 raster to tiff reasters. 
Its main source code repository is https://github.com/SaifAati/JP2toTiff.git.


# Installation

To install `jp2totiff` from PyPI:

    pip install jp2totiff

Alternatively, to install `jp2totiff` from sources:

    git clone https://github.com/SaifAati/JP2toTiff.git
    cd JP2totiff
    pip install -e .


